body{margin:0;padding:0;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen,Ubuntu,Cantarell,Fira Sans,Droid Sans,Helvetica Neue,sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;background-color:#fff}code{font-family:source-code-pro,Menlo,Monaco,Consolas,Courier New,monospace}.App{text-align:center}.App-logo{-webkit-animation:App-logo-spin 20s linear infinite;animation:App-logo-spin 20s linear infinite;height:40vmin;pointer-events:none}.App-header{background-color:#282c34;min-height:100vh;display:flex;flex-direction:column;align-items:center;justify-content:center;font-size:calc(10px + 2vmin);color:#fff}.App-link{color:#61dafb}.report-severity{text-align:center;vertical-align:middle!important}.report-severity-low{background-color:#39a5dc!important}.report-severity-medium{background-color:#f0ab00!important}.report-severity-high{background-color:#c00!important}.filter-button{float:left;top:0;margin-right:1em;margin-top:1em}@-webkit-keyframes App-logo-spin{0%{-webkit-transform:rotate(0deg);transform:rotate(0deg)}to{-webkit-transform:rotate(1turn);transform:rotate(1turn)}}@keyframes App-logo-spin{0%{-webkit-transform:rotate(0deg);transform:rotate(0deg)}to{-webkit-transform:rotate(1turn);transform:rotate(1turn)}}.filter-panel-parent{position:absolute;width:30rem;box-shadow:0 2px 2px 0 hsla(0,0%,39.2%,.75);z-index:666;height:100%;top:0;left:0;background-color:#f0f0f0;padding:0;margin:0}@media screen and (max-width:750px){.filter-panel-parent{width:100%}}@media screen and (max-device-width:768px) and (orientation:portrait){.filter-panel-parent{width:100%}}.filter-panel-header{padding-top:1em;padding-bottom:1em;padding-left:.5em;border-bottom:1px solid #ccc;background-color:#646a6e;color:#f0f0f0}.filter-panel-header-inner{display:inline-block;padding-left:1em}.filter-panel-header h2{margin:0;padding:0;line-height:1em}.filter-panel-header-close{float:right;padding-right:1em;color:#a0a0a0}.filter-panel-header a{color:#a0a0a0}.side-panel-parent{position:absolute;width:45rem;box-shadow:-2px 0 2px 0 hsla(0,0%,39.2%,.75);z-index:666;height:100%;top:0;right:0;background-color:#f0f0f0;padding:0;margin:0;overflow:auto}@media screen and (max-width:750px){.side-panel-parent{width:100%}}@media screen and (max-device-width:768px) and (orientation:portrait){.side-panel-parent{width:100%}}.side-panel-header{padding-top:1em;padding-bottom:1em;padding-left:.5em;border-bottom:1px solid #ccc;background-color:#646a6e;color:#f0f0f0}.side-panel-header-inner{display:inline-block;padding-left:1em}.side-panel-header h2{margin:0;padding:0;line-height:1em}.side-panel-header-close{float:right;padding-right:1em;color:#a0a0a0}.side-panel-header a{color:#a0a0a0}
/*# sourceMappingURL=main.2c406905.chunk.css.map */